svn commit: r297924 - in projects/zfsd/head: cddl/sbin/zfsd cddl/sbin/zfsd/tests etc/mtree lib/libdevdctl

Alan Somers asomers at FreeBSD.org
Wed Apr 13 15:22:47 UTC 2016


Author: asomers
Date: Wed Apr 13 15:22:43 2016
New Revision: 297924
URL: https://svnweb.freebsd.org/changeset/base/297924

Log:
  Finish renaming libdevctl to libdevdctl, started by r289684
  
  r289684 only changed the source path and the shlib name for libdevctl.  This
  change updates the install directory and the namespace too.
  
  Sponsored by:	Spectra Logic Corp

Modified:
  projects/zfsd/head/cddl/sbin/zfsd/callout.cc
  projects/zfsd/head/cddl/sbin/zfsd/case_file.cc
  projects/zfsd/head/cddl/sbin/zfsd/case_file.h
  projects/zfsd/head/cddl/sbin/zfsd/tests/zfsd_unittest.cc
  projects/zfsd/head/cddl/sbin/zfsd/vdev.cc
  projects/zfsd/head/cddl/sbin/zfsd/vdev.h
  projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.cc
  projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.h
  projects/zfsd/head/cddl/sbin/zfsd/zfsd.cc
  projects/zfsd/head/cddl/sbin/zfsd/zfsd.h
  projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.cc
  projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.h
  projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.cc
  projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.h
  projects/zfsd/head/cddl/sbin/zfsd/zfsd_main.cc
  projects/zfsd/head/cddl/sbin/zfsd/zpool_list.cc
  projects/zfsd/head/etc/mtree/BSD.include.dist
  projects/zfsd/head/lib/libdevdctl/Makefile
  projects/zfsd/head/lib/libdevdctl/consumer.cc
  projects/zfsd/head/lib/libdevdctl/consumer.h
  projects/zfsd/head/lib/libdevdctl/event.cc
  projects/zfsd/head/lib/libdevdctl/event.h
  projects/zfsd/head/lib/libdevdctl/event_buffer.cc
  projects/zfsd/head/lib/libdevdctl/event_buffer.h
  projects/zfsd/head/lib/libdevdctl/event_factory.cc
  projects/zfsd/head/lib/libdevdctl/event_factory.h
  projects/zfsd/head/lib/libdevdctl/exception.cc
  projects/zfsd/head/lib/libdevdctl/exception.h
  projects/zfsd/head/lib/libdevdctl/guid.cc
  projects/zfsd/head/lib/libdevdctl/guid.h
  projects/zfsd/head/lib/libdevdctl/reader.cc
  projects/zfsd/head/lib/libdevdctl/reader.h

Modified: projects/zfsd/head/cddl/sbin/zfsd/callout.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/callout.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/callout.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -47,11 +47,11 @@
 #include <map>
 #include <string>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/consumer.h>
-#include <devctl/exception.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/consumer.h>
+#include <devdctl/exception.h>
 
 #include "callout.h"
 #include "vdev_iterator.h"

Modified: projects/zfsd/head/cddl/sbin/zfsd/case_file.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/case_file.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/case_file.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -57,11 +57,11 @@
 #include <map>
 #include <string>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/exception.h>
-#include <devctl/consumer.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/exception.h>
+#include <devdctl/consumer.h>
 
 #include "callout.h"
 #include "vdev_iterator.h"
@@ -82,12 +82,12 @@ using std::stringstream;
 using std::setfill;
 using std::setw;
 
-using DevCtl::Event;
-using DevCtl::EventBuffer;
-using DevCtl::EventFactory;
-using DevCtl::EventList;
-using DevCtl::Guid;
-using DevCtl::ParseException;
+using DevdCtl::Event;
+using DevdCtl::EventBuffer;
+using DevdCtl::EventFactory;
+using DevdCtl::EventList;
+using DevdCtl::Guid;
+using DevdCtl::ParseException;
 
 /*-------------------------- File-scoped classes ----------------------------*/
 /**

Modified: projects/zfsd/head/cddl/sbin/zfsd/case_file.h
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/case_file.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/case_file.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -94,7 +94,7 @@ public:
 	 * \return  If found, a pointer to a valid CaseFile object.
 	 *          Otherwise NULL.
 	 */
-	static CaseFile *Find(DevCtl::Guid poolGUID, DevCtl::Guid vdevGUID);
+	static CaseFile *Find(DevdCtl::Guid poolGUID, DevdCtl::Guid vdevGUID);
 
 	/**
 	 * \brief Find a CaseFile object by a vdev's current/last known
@@ -113,7 +113,7 @@ public:
 	 * \param poolGUID	Only reevaluate cases for this pool
 	 * \param event		Try to consume this event with the casefile
 	 */
-	static void ReEvaluateByGuid(DevCtl::Guid poolGUID,
+	static void ReEvaluateByGuid(DevdCtl::Guid poolGUID,
 				     const ZfsEvent &event);
 
 	/**
@@ -145,8 +145,8 @@ public:
 	 */
 	static void      PurgeAll();
 
-	DevCtl::Guid  PoolGUID()       const;
-	DevCtl::Guid  VdevGUID()       const;
+	DevdCtl::Guid PoolGUID()       const;
+	DevdCtl::Guid VdevGUID()       const;
 	vdev_state    VdevState()      const;
 	const string &PoolGUIDString() const;
 	const string &VdevGUIDString() const;
@@ -183,7 +183,7 @@ public:
 	/**
 	 * \brief Register an itimer callout for the given event, if necessary
 	 */
-	virtual void RegisterCallout(const DevCtl::Event &event);
+	virtual void RegisterCallout(const DevdCtl::Event &event);
 
 	/**
 	 * \brief Close a case if it is no longer relevant.
@@ -290,7 +290,7 @@ protected:
 	 * \param prefix  If not NULL, this prefix will be prepended to
 	 *                every event in the file.
 	 */
-	void SerializeEvList(const DevCtl::EventList events, int fd,
+	void SerializeEvList(const DevdCtl::EventList events, int fd,
 			     const char* prefix=NULL) const;
 
 	/**
@@ -362,21 +362,21 @@ protected:
 	 * \brief A list of soft error events counted against the health of
 	 *        a vdev.
 	 */
-	DevCtl::EventList m_events;
+	DevdCtl::EventList m_events;
 
 	/**
 	 * \brief A list of soft error events waiting for a grace period
 	 *        expiration before being counted against the health of
 	 *        a vdev.
 	 */
-	DevCtl::EventList m_tentativeEvents;
+	DevdCtl::EventList m_tentativeEvents;
 
-	DevCtl::Guid	  m_poolGUID;
-	DevCtl::Guid	  m_vdevGUID;
-	vdev_state	  m_vdevState;
-	string		  m_poolGUIDString;
-	string		  m_vdevGUIDString;
-	string		  m_vdevPhysPath;
+	DevdCtl::Guid	   m_poolGUID;
+	DevdCtl::Guid	   m_vdevGUID;
+	vdev_state	   m_vdevState;
+	string		   m_poolGUIDString;
+	string		   m_vdevGUIDString;
+	string		   m_vdevPhysPath;
 
 	/**
 	 * \brief Callout activated when a grace period
@@ -387,13 +387,13 @@ private:
 	nvlist_t	*CaseVdev(zpool_handle_t *zhp)	const;
 };
 
-inline DevCtl::Guid
+inline DevdCtl::Guid
 CaseFile::PoolGUID() const
 {
 	return (m_poolGUID);
 }
 
-inline DevCtl::Guid
+inline DevdCtl::Guid
 CaseFile::VdevGUID() const
 {
 	return (m_vdevGUID);

Modified: projects/zfsd/head/cddl/sbin/zfsd/tests/zfsd_unittest.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/tests/zfsd_unittest.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/tests/zfsd_unittest.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -45,11 +45,11 @@
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/exception.h>
-#include <devctl/consumer.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/exception.h>
+#include <devdctl/consumer.h>
 
 #include <zfsd/callout.h>
 #include <zfsd/vdev_iterator.h>
@@ -71,12 +71,12 @@ __FBSDID("$FreeBSD$");
 using std::string;
 using std::stringstream;
 
-using DevCtl::Event;
-using DevCtl::EventBuffer;
-using DevCtl::EventFactory;
-using DevCtl::EventList;
-using DevCtl::Guid;
-using DevCtl::NVPairMap;
+using DevdCtl::Event;
+using DevdCtl::EventBuffer;
+using DevdCtl::EventFactory;
+using DevdCtl::EventList;
+using DevdCtl::Guid;
+using DevdCtl::NVPairMap;
 
 /* redefine zpool_handle here because libzfs_impl.h is not includable */
 struct zpool_handle

Modified: projects/zfsd/head/cddl/sbin/zfsd/vdev.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/vdev.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/vdev.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -48,11 +48,11 @@
 #include <string>
 #include <sstream>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/exception.h>
-#include <devctl/consumer.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/exception.h>
+#include <devdctl/consumer.h>
 
 #include "vdev.h"
 #include "vdev_iterator.h"

Modified: projects/zfsd/head/cddl/sbin/zfsd/vdev.h
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/vdev.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/vdev.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -42,7 +42,7 @@
  *    #include <string>
  *    #include <list>
  *
- *    #include <devctl/guid.h>
+ *    #include <devdctl/guid.h>
  */
 #ifndef	_VDEV_H_
 #define	_VDEV_H_
@@ -115,9 +115,9 @@ public:
 	 */
 	std::list<Vdev>		 Children();
 
-	virtual DevCtl::Guid	 GUID()		const;
+	virtual DevdCtl::Guid	 GUID()		const;
 	bool			 IsSpare()	const;
-	virtual DevCtl::Guid	 PoolGUID()	const;
+	virtual DevdCtl::Guid	 PoolGUID()	const;
 	virtual vdev_state	 State()	const;
 	std::string		 Path()		const;
 	virtual std::string	 PhysicalPath()	const;
@@ -135,8 +135,8 @@ public:
 private:
 	void			 VdevLookupGuid();
 	bool			 VdevLookupPoolGuid();
-	DevCtl::Guid		 m_poolGUID;
-	DevCtl::Guid		 m_vdevGUID;
+	DevdCtl::Guid		 m_poolGUID;
+	DevdCtl::Guid		 m_vdevGUID;
 	nvlist_t		*m_poolConfig;
 	nvlist_t		*m_config;
 };
@@ -145,13 +145,13 @@ private:
 extern Vdev NonexistentVdev;
 
 //- Vdev Inline Public Methods ------------------------------------------------
-inline DevCtl::Guid
+inline DevdCtl::Guid
 Vdev::PoolGUID() const
 {
 	return (m_poolGUID);
 }
 
-inline DevCtl::Guid
+inline DevdCtl::Guid
 Vdev::GUID() const
 {
 	return (m_vdevGUID);

Modified: projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -46,15 +46,15 @@
 #include <list>
 #include <string>
 
-#include <devctl/exception.h>
-#include <devctl/guid.h>
+#include <devdctl/exception.h>
+#include <devdctl/guid.h>
 
 #include "vdev.h"
 #include "vdev_iterator.h"
 #include "zfsd_exception.h"
 
 /*============================ Namespace Control =============================*/
-using DevCtl::Guid;
+using DevdCtl::Guid;
 
 /*=========================== Class Implementations ==========================*/
 /*------------------------------- VdevIterator -------------------------------*/

Modified: projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.h
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/vdev_iterator.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -102,7 +102,7 @@ public:
 	 * Upon return, the VdevIterator's cursor points to the vdev just
 	 * past the returned vdev or end() if no matching vdev is found.
 	 */
-	nvlist_t *Find(DevCtl::Guid vdevGUID);
+	nvlist_t *Find(DevdCtl::Guid vdevGUID);
 
 	/**
 	 * \brief Perform the specified operation on each leaf member of

Modified: projects/zfsd/head/cddl/sbin/zfsd/zfsd.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/zfsd.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zfsd.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -48,10 +48,10 @@
  *    #include <map>
  *    #include <string>
  *
- *    #include <devctl/guid.h>
- *    #include <devctl/event.h>
- *    #include <devctl/event_factory.h>
- *    #include <devctl/consumer.h>
+ *    #include <devdctl/guid.h>
+ *    #include <devdctl/event.h>
+ *    #include <devdctl/event_factory.h>
+ *    #include <devdctl/consumer.h>
  *
  *    #include "vdev_iterator.h"
  */
@@ -81,7 +81,7 @@ extern libzfs_handle_t *g_zfsHandle;
 /**
  * Static singleton orchestrating the operations of the ZFS daemon program.
  */
-class ZfsDaemon : public DevCtl::Consumer
+class ZfsDaemon : public DevdCtl::Consumer
 {
 public:
 	/** Return the ZfsDaemon singleton. */
@@ -222,7 +222,7 @@ private:
 	 */
 	static bool				s_consumingEvents;
 
-	static DevCtl::EventFactory::Record	s_registryEntries[];
+	static DevdCtl::EventFactory::Record	s_registryEntries[];
 };
 
 #endif	/* _ZFSD_H_ */

Modified: projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -46,11 +46,11 @@
 #include <sstream>
 #include <string>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/exception.h>
-#include <devctl/consumer.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/exception.h>
+#include <devdctl/consumer.h>
 
 #include "callout.h"
 #include "vdev_iterator.h"
@@ -63,9 +63,9 @@
 
 __FBSDID("$FreeBSD$");
 /*============================ Namespace Control =============================*/
-using DevCtl::Event;
-using DevCtl::Guid;
-using DevCtl::NVPairMap;
+using DevdCtl::Event;
+using DevdCtl::Guid;
+using DevdCtl::NVPairMap;
 using std::stringstream;
 
 /*=========================== Class Implementations ==========================*/
@@ -217,18 +217,18 @@ DevfsEvent::Process() const
 //- DevfsEvent Protected Methods -----------------------------------------------
 DevfsEvent::DevfsEvent(Event::Type type, NVPairMap &nvpairs,
 			       const string &eventString)
- : DevCtl::DevfsEvent(type, nvpairs, eventString)
+ : DevdCtl::DevfsEvent(type, nvpairs, eventString)
 {
 }
 
 DevfsEvent::DevfsEvent(const DevfsEvent &src)
- : DevCtl::DevfsEvent::DevfsEvent(src)
+ : DevdCtl::DevfsEvent::DevfsEvent(src)
 {
 }
 
 /*--------------------------------- ZfsEvent ---------------------------------*/
 //- ZfsEvent Static Public Methods ---------------------------------------------
-DevCtl::Event *
+DevdCtl::Event *
 ZfsEvent::Builder(Event::Type type, NVPairMap &nvpairs,
 		  const string &eventString)
 {
@@ -343,12 +343,12 @@ ZfsEvent::Process() const
 //- ZfsEvent Protected Methods -------------------------------------------------
 ZfsEvent::ZfsEvent(Event::Type type, NVPairMap &nvpairs,
 			   const string &eventString)
- : DevCtl::ZfsEvent(type, nvpairs, eventString)
+ : DevdCtl::ZfsEvent(type, nvpairs, eventString)
 {
 }
 
 ZfsEvent::ZfsEvent(const ZfsEvent &src)
- : DevCtl::ZfsEvent(src)
+ : DevdCtl::ZfsEvent(src)
 {
 }
 

Modified: projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.h
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -44,8 +44,8 @@
 #include <list>
 #include <sstream>
 
-#include <devctl/exception.h>
-#include <devctl/guid.h>
+#include <devdctl/exception.h>
+#include <devdctl/guid.h>
 
 #include <libzfs.h>
 
@@ -61,7 +61,7 @@ using std::stringstream;
 /*=========================== Class Implementations ==========================*/
 /*------------------------------- ZfsdException ------------------------------*/
 ZfsdException::ZfsdException(const char *fmt, ...)
- : DevCtl::Exception(),
+ : DevdCtl::Exception(),
    m_poolConfig(NULL),
    m_vdevConfig(NULL)
 {
@@ -73,7 +73,7 @@ ZfsdException::ZfsdException(const char 
 }
 
 ZfsdException::ZfsdException(zpool_handle_t *pool, const char *fmt, ...)
- : DevCtl::Exception(),
+ : DevdCtl::Exception(),
    m_poolConfig(zpool_get_config(pool, NULL)),
    m_vdevConfig(NULL)
 {
@@ -85,7 +85,7 @@ ZfsdException::ZfsdException(zpool_handl
 }
 
 ZfsdException::ZfsdException(nvlist_t *poolConfig, const char *fmt, ...)
- : DevCtl::Exception(),
+ : DevdCtl::Exception(),
    m_poolConfig(poolConfig),
    m_vdevConfig(NULL)
 {

Modified: projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.h
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -39,7 +39,7 @@
  * Header requirements:
  *     #include <string>
  *
- *     #include <devctl/exception.h>
+ *     #include <devdctl/exception.h>
  */
 #ifndef	_ZFSD_EXCEPTION_H_
 #define	_ZFSD_EXCEPTION_H_
@@ -56,7 +56,7 @@ typedef struct nvlist nvlist_t;
 /**
  * \brief Class allowing unified reporting/logging of exceptional events.
  */
-class ZfsdException : public DevCtl::Exception
+class ZfsdException : public DevdCtl::Exception
 {
 public:
 	/**

Modified: projects/zfsd/head/cddl/sbin/zfsd/zfsd_main.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/zfsd_main.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zfsd_main.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -47,11 +47,11 @@
 #include <map>
 #include <string>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/exception.h>
-#include <devctl/consumer.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/exception.h>
+#include <devdctl/consumer.h>
 
 #include "vdev_iterator.h"
 #include "zfsd.h"

Modified: projects/zfsd/head/cddl/sbin/zfsd/zpool_list.cc
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/zpool_list.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zpool_list.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -46,11 +46,11 @@
 #include <map>
 #include <string>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/exception.h>
-#include <devctl/consumer.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/exception.h>
+#include <devdctl/consumer.h>
 
 #include "vdev.h"
 #include "vdev_iterator.h"
@@ -58,7 +58,7 @@
 #include "zfsd.h"
 
 /*============================ Namespace Control =============================*/
-using DevCtl::Guid;
+using DevdCtl::Guid;
 
 /*=========================== Class Implementations ==========================*/
 /*--------------------------------- ZpoolList --------------------------------*/

Modified: projects/zfsd/head/etc/mtree/BSD.include.dist
==============================================================================
--- projects/zfsd/head/etc/mtree/BSD.include.dist	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/etc/mtree/BSD.include.dist	Wed Apr 13 15:22:43 2016	(r297924)
@@ -153,7 +153,7 @@
         wi
         ..
     ..
-    devctl
+    devdctl
     ..
     edit
         readline

Modified: projects/zfsd/head/lib/libdevdctl/Makefile
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/Makefile	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/Makefile	Wed Apr 13 15:22:43 2016	(r297924)
@@ -12,7 +12,7 @@ SRCS=	consumer.cc		\
 	exception.cc		\
 	guid.cc
 
-INCSDIR= ${INCLUDEDIR}/devctl
+INCSDIR= ${INCLUDEDIR}/devdctl
 
 WARNS?=	3
 SHLIB_MAJOR=	0

Modified: projects/zfsd/head/lib/libdevdctl/consumer.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/consumer.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/consumer.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -65,11 +65,11 @@ __FBSDID("$FreeBSD$");
 
 /*============================ Namespace Control =============================*/
 using std::string;
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*============================= Class Definitions ============================*/
-/*----------------------------- DevCtl::Consumer -----------------------------*/
+/*----------------------------- DevdCtl::Consumer ----------------------------*/
 //- Consumer Static Private Data -----------------------------------------------
 const char Consumer::s_devdSockPath[] = "/var/run/devd.seqpacket.pipe";
 
@@ -255,4 +255,4 @@ Consumer::EventsPending()
 	return ((fds->revents & POLLIN) != 0);
 }
 
-} // namespace DevCtl
+} // namespace DevdCtl

Modified: projects/zfsd/head/lib/libdevdctl/consumer.h
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/consumer.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/consumer.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -33,13 +33,13 @@
  */
 
 /**
- * \file devctl_consumer.h
+ * \file devdctl_consumer.h
  */
-#ifndef	_DEVCTL_CONSUMER_H_
-#define	_DEVCTL_CONSUMER_H_
+#ifndef	_DEVDCTL_CONSUMER_H_
+#define	_DEVDCTL_CONSUMER_H_
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*=========================== Forward Declarations ===========================*/
@@ -48,7 +48,7 @@ class EventBuffer;
 class FDReader;
 
 /*============================ Class Declarations ============================*/
-/*----------------------------- DevCtl::Consumer -----------------------------*/
+/*----------------------------- DevdCtl::Consumer ----------------------------*/
 
 /**
  */
@@ -126,7 +126,7 @@ protected:
 
 	enum {
 		/*
-		 * The maximum event size supported by libdevctl.
+		 * The maximum event size supported by libdevdctl.
 		 */
 		MAX_EVENT_SIZE = 8192,
 	};
@@ -182,5 +182,5 @@ Consumer::GetFactory()
 	return (m_eventFactory);
 }
 
-} // namespace DevCtl
-#endif	/* _DEVCTL_CONSUMER_H_ */
+} // namespace DevdCtl
+#endif	/* _DEVDCTL_CONSUMER_H_ */

Modified: projects/zfsd/head/lib/libdevdctl/event.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/event_buffer.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/event_buffer.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -33,13 +33,13 @@
  */
 
 /**
- * \file devctl_event_buffer.h
+ * \file devdctl_event_buffer.h
  */
-#ifndef	_DEVCTL_EVENT_BUFFER_H_
-#define	_DEVCTL_EVENT_BUFFER_H_
+#ifndef	_DEVDCTL_EVENT_BUFFER_H_
+#define	_DEVDCTL_EVENT_BUFFER_H_
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*=========================== Forward Declarations ===========================*/
@@ -184,5 +184,5 @@ EventBuffer::NextEventMaxLen() const
 	return (m_validLen - m_nextEventOffset);
 }
 
-} // namespace DevCtl
-#endif	/* _DEVCTL_EVENT_BUFFER_H_ */
+} // namespace DevdCtl
+#endif	/* _DEVDCTL_EVENT_BUFFER_H_ */

Modified: projects/zfsd/head/lib/libdevdctl/event_factory.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/event_factory.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/event_factory.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -50,7 +50,7 @@ __FBSDID("$FreeBSD$");
 #define NUM_ELEMENTS(x) (sizeof(x) / sizeof(*x))
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*=========================== Class Implementations ==========================*/
@@ -96,4 +96,4 @@ EventFactory::Build(Event::Type type, NV
 	return (buildMethod(type, nvpairs, eventString));
 }
 
-} // namespace DevCtl
+} // namespace DevdCtl

Modified: projects/zfsd/head/lib/libdevdctl/event_factory.h
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/event_factory.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/event_factory.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -33,14 +33,14 @@
  */
 
 /**
- * \file devctl_event_factory.h
+ * \file devdctl_event_factory.h
  */
 
-#ifndef _DEVCTL_EVENT_FACTORY_H_
-#define	_DEVCTL_EVENT_FACTORY_H_
+#ifndef _DEVDCTL_EVENT_FACTORY_H_
+#define	_DEVDCTL_EVENT_FACTORY_H_
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*============================= Class Definitions ============================*/
@@ -90,5 +90,5 @@ EventFactory::GetRegistry() const
 	return (m_registry);
 }
 
-} // namespace DevCtl
-#endif /*_DEVCTL_EVENT_FACTORY_H_ */
+} // namespace DevdCtl
+#endif /*_DEVDCTL_EVENT_FACTORY_H_ */

Modified: projects/zfsd/head/lib/libdevdctl/exception.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/exception.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/exception.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -50,7 +50,7 @@ __FBSDID("$FreeBSD$");
 using std::string;
 using std::stringstream;
 using std::endl;
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*=========================== Class Implementations ==========================*/
@@ -122,4 +122,4 @@ ParseException::ParseException(Type type
 	GetString() = logstream.str();
 }
 
-} // namespace DevCtl
+} // namespace DevdCtl

Modified: projects/zfsd/head/lib/libdevdctl/exception.h
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/exception.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/exception.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -36,11 +36,11 @@
  * Definition of the ZfsdException class hierarchy.  All exceptions
  * explicitly thrown by Zfsd are defined here.
  */
-#ifndef	_DEVCTL_EXCEPTION_H_
-#define	_DEVCTL_EXCEPTION_H_
+#ifndef	_DEVDCTL_EXCEPTION_H_
+#define	_DEVDCTL_EXCEPTION_H_
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*============================= Class Definitions ============================*/
@@ -162,5 +162,5 @@ ParseException::GetOffset() const
 	return (m_offset);
 }
 
-} // namespace DevCtl
-#endif /* _DEVCTL_EXCEPTION_H_ */
+} // namespace DevdCtl
+#endif /* _DEVDCTL_EXCEPTION_H_ */

Modified: projects/zfsd/head/lib/libdevdctl/guid.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/guid.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/guid.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -51,7 +51,7 @@
 __FBSDID("$FreeBSD$");
 /*============================ Namespace Control =============================*/
 using std::string;
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*=========================== Class Implementations ==========================*/
@@ -79,4 +79,4 @@ operator<< (std::ostream& out, Guid g)
 	return (out);
 }
 
-} // namespace DevCtl
+} // namespace DevdCtl

Modified: projects/zfsd/head/lib/libdevdctl/guid.h
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/guid.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/guid.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -33,15 +33,15 @@
  */
 
 /**
- * \file devctl_guid.h
+ * \file devdctl_guid.h
  *
  * Definition of the Guid class.
  */
-#ifndef	_DEVCTL_GUID_H_
-#define	_DEVCTL_GUID_H_
+#ifndef	_DEVDCTL_GUID_H_
+#define	_DEVDCTL_GUID_H_
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*============================= Class Definitions ============================*/
@@ -139,5 +139,5 @@ Guid::operator bool() const
 /** Convert the GUID into its string representation */
 std::ostream& operator<< (std::ostream& out, Guid g);
 
-} // namespace DevCtl
-#endif /* _DEVCTL_GUID_H_ */
+} // namespace DevdCtl
+#endif /* _DEVDCTL_GUID_H_ */

Modified: projects/zfsd/head/lib/libdevdctl/reader.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/reader.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/reader.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -49,7 +49,7 @@
 __FBSDID("$FreeBSD$");
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 //- FDReader Public Methods ---------------------------------------------------
@@ -96,4 +96,4 @@ IstreamReader::in_avail() const

*** DIFF OUTPUT TRUNCATED AT 1000 LINES ***


More information about the svn-src-projects mailing list
--- projects/zfsd/head/cddl/sbin/zfsd/zfsd.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zfsd.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -33,7 +33,7 @@
 /**
  * \file zfsd.cc
  *
  * The ZFS daemon consumes kernel devctl(4) event data via devd(8)'s
  * unix domain socket in order to react to system changes that impact
  * the function of ZFS storage pools.  The goal of this daemon is to
  * provide similar functionality to the Solaris ZFS Diagnostic Engine
@@ -57,11 +57,11 @@
 #include <map>
 #include <string>
 
-#include <devctl/guid.h>
-#include <devctl/event.h>
-#include <devctl/event_factory.h>
-#include <devctl/exception.h>
-#include <devctl/consumer.h>
+#include <devdctl/guid.h>
+#include <devdctl/event.h>
+#include <devdctl/event_factory.h>
+#include <devdctl/exception.h>
+#include <devdctl/consumer.h>
 
 #include "callout.h"
 #include "vdev_iterator.h"
@@ -79,9 +79,9 @@ __FBSDID("$FreeBSD$");
 #define NUM_ELEMENTS(x) (sizeof(x) / sizeof(*x))
 
 /*============================ Namespace Control =============================*/
-using DevCtl::Event;
-using DevCtl::EventFactory;
-using DevCtl::EventList;
+using DevdCtl::Event;
+using DevdCtl::EventFactory;
+using DevdCtl::EventList;
 
 /*================================ Global Data ===============================*/
 int              g_debug = 0;
@@ -141,7 +141,7 @@ ZfsDaemon::Run()
 
 			daemon.EventLoop();
 
-		} catch (const DevCtl::Exception &exp) {
+		} catch (const DevdCtl::Exception &exp) {
 			exp.Log();
 		}
 	}
@@ -266,7 +266,7 @@ ZfsDaemon::RescanSystem()
 	int		  result;
 
         /*
 	 * The devctl system doesn't replay events for new consumers
 	 * of the interface.  Emit manufactured DEVFS arrival events
 	 * for any devices that already before we started or during
 	 * periods where we've lost our connection to devd.
@@ -33,7 +33,7 @@
  * \file zfsd.cc
  *
- * The ZFS daemon consumes kernel devctl(4) event data via devd(8)'s
+ * The ZFS daemon consumes kernel devdctl(4) event data via devd(8)'s
  * unix domain socket in order to react to system changes that impact
  * the function of ZFS storage pools.  The goal of this daemon is to
@@ -266,7 +266,7 @@ ZfsDaemon::RescanSystem()
 
         /*
-	 * The devctl system doesn't replay events for new consumers
+	 * The devdctl system doesn't replay events for new consumers
 	 * of the interface.  Emit manufactured DEVFS arrival events
 	 * for any devices that already before we started or during

Modified: projects/zfsd/head/cddl/sbin/zfsd/zfsd.h
==============================================================================
--- projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/cddl/sbin/zfsd/zfsd_event.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -36,15 +36,15 @@
  * \file dev_ctl_event.h
  *
  * \brief Class hierarchy used to express events received via
  *        the devctl API.
  *
  * Header requirements:
  *    #include <string>
  *    #include <list>
  *    #include <map>
  *
- *    #include <devctl/guid.h>
- *    #include <devctl/event.h>
+ *    #include <devdctl/guid.h>
+ *    #include <devdctl/event.h>
  */
 
 #ifndef _ZFSD_EVENT_H_
@@ -62,13 +62,13 @@ typedef struct nvlist nvlist_t;
 
 /*============================= Class Definitions ============================*/
 /*-------------------------------- DevfsEvent --------------------------------*/
-class DevfsEvent : public DevCtl::DevfsEvent
+class DevfsEvent : public DevdCtl::DevfsEvent
 {
 public:
 	/** Specialized DevCtlEvent object factory for Devfs events. */
 	static BuildMethod Builder;
 
-	virtual DevCtl::Event *DeepCopy() const;
+	virtual DevdCtl::Event *DeepCopy() const;
 
 	/**
 	 * Interpret and perform any actions necessary to
@@ -114,17 +114,17 @@ protected:
 	DevfsEvent(const DevfsEvent &src);
 
 	/** Constructor */
-	DevfsEvent(Type, DevCtl::NVPairMap &, const string &);
+	DevfsEvent(Type, DevdCtl::NVPairMap &, const string &);
 };
 
 /*--------------------------------- ZfsEvent ---------------------------------*/
-class ZfsEvent : public DevCtl::ZfsEvent
+class ZfsEvent : public DevdCtl::ZfsEvent
 {
 public:
 	/** Specialized DevCtlEvent object factory for ZFS events. */
 	static BuildMethod Builder;
 
-	virtual DevCtl::Event *DeepCopy() const;
+	virtual DevdCtl::Event *DeepCopy() const;
 
 	/**
 	 * Interpret and perform any actions necessary to
@@ -138,7 +138,7 @@ protected:
 	ZfsEvent(const ZfsEvent &src);
 
 	/** Constructor */
-	ZfsEvent(Type, DevCtl::NVPairMap &, const string &);
+	ZfsEvent(Type, DevdCtl::NVPairMap &, const string &);
 
 	/**
 	 * Detach any spares that are no longer needed, but were not
@@ -36,15 +36,15 @@
  *
  * \brief Class hierarchy used to express events received via
- *        the devctl API.
+ *        the devdctl API.
  *
  * Header requirements:
@@ -62,13 +62,13 @@ typedef struct nvlist nvlist_t;
 {
 public:
-	/** Specialized DevCtlEvent object factory for Devfs events. */
+	/** Specialized DevdCtlEvent object factory for Devfs events. */
 	static BuildMethod Builder;
 
@@ -114,17 +114,17 @@ protected:
 {
 public:
-	/** Specialized DevCtlEvent object factory for ZFS events. */
+	/** Specialized DevdCtlEvent object factory for ZFS events. */
 	static BuildMethod Builder;
 

Modified: projects/zfsd/head/cddl/sbin/zfsd/zfsd_exception.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/event.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/event.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -34,7 +34,7 @@
  * \file event.cc
  *
  * Implementation of the class hierarchy used to express events
  * received via the devctl API.
  */
 #include <sys/cdefs.h>
 #include <sys/disk.h>
@@ -74,7 +74,7 @@ using std::endl;
 using std::string;
 using std::stringstream;
 
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*=========================== Class Implementations ==========================*/
@@ -304,7 +304,7 @@ Event::ParseEventString(Event::Type type
 		/*
 		 * Find the start of the key by backing up until
 		 * we hit whitespace or '!' (event type "notice").
 		 * Due to the devctl format, all key/value pair must
 		 * start with one of these two characters.
 		 */
 		start = eventString.find_last_of("! \t\n", end);
@@ -554,4 +554,4 @@ ZfsEvent::ZfsEvent(const ZfsEvent &src)
 {
 }
 
-} // namespace DevCtl
+} // namespace DevdCtl
@@ -34,7 +34,7 @@
  *
  * Implementation of the class hierarchy used to express events
- * received via the devctl API.
+ * received via the devdctl API.
  */
 #include <sys/cdefs.h>
@@ -304,7 +304,7 @@ Event::ParseEventString(Event::Type type
 		 * Find the start of the key by backing up until
 		 * we hit whitespace or '!' (event type "notice").
-		 * Due to the devctl format, all key/value pair must
+		 * Due to the devdctl format, all key/value pair must
 		 * start with one of these two characters.
 		 */

Modified: projects/zfsd/head/lib/libdevdctl/event.h
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/event.h	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/event.h	Wed Apr 13 15:22:43 2016	(r297924)
@@ -33,17 +33,17 @@
  */
 
 /**
- * \file devctl_event.h
+ * \file devdctl_event.h
  *
  * \brief Class hierarchy used to express events received via
  *        the devctl API.
  */
 
-#ifndef _DEVCTL_EVENT_H_
-#define	_DEVCTL_EVENT_H_
+#ifndef _DEVDCTL_EVENT_H_
+#define	_DEVDCTL_EVENT_H_
 
 /*============================ Namespace Control =============================*/
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*=========================== Forward Declarations ===========================*/
@@ -140,9 +140,9 @@ public:
 	Type GetType()					 const;
 
 	/**
 	 * Get the orginal DevCtl event string for this event.
 	 *
 	 * \return  The DevCtl event string.
 	 */
 	const std::string &GetEventString()		 const;
 
@@ -375,5 +375,5 @@ ZfsEvent::VdevGUID() const
 	return (m_vdevGUID);
 }
 
-} // namespace DevCtl
-#endif /*_DEVCTL_EVENT_H_ */
+} // namespace DevdCtl
+#endif /*_DEVDCTL_EVENT_H_ */
@@ -33,17 +33,17 @@
  *
  * \brief Class hierarchy used to express events received via
- *        the devctl API.
+ *        the devdctl API.
  */
 
@@ -140,9 +140,9 @@ public:
 
 	/**
-	 * Get the orginal DevCtl event string for this event.
+	 * Get the orginal DevdCtl event string for this event.
 	 *
@@ -140,9 +140,9 @@ public:
 	 *
-	 * \return  The DevCtl event string.
+	 * \return  The DevdCtl event string.
 	 */
 	const std::string &GetEventString()		 const;

Modified: projects/zfsd/head/lib/libdevdctl/event_buffer.cc
==============================================================================
--- projects/zfsd/head/lib/libdevdctl/event_buffer.cc	Wed Apr 13 14:59:50 2016	(r297923)
+++ projects/zfsd/head/lib/libdevdctl/event_buffer.cc	Wed Apr 13 15:22:43 2016	(r297924)
@@ -55,14 +55,14 @@ __FBSDID("$FreeBSD$");
 /*============================ Namespace Control =============================*/
 using std::string;
 using std::stringstream;
-namespace DevCtl
+namespace DevdCtl
 {
 
 /*============================= Class Definitions ============================*/
 /*-------------------------------- EventBuffer -------------------------------*/
 //- EventBuffer Static Data ----------------------------------------------------
 /**
  * NOTIFY, NOMATCH, ATTACH, DETACH.  See DevCtlEvent::Type.
  */
 const char EventBuffer::s_eventStartTokens[] = "!?+-";
 
@@ -213,4 +213,4 @@ EventBuffer::Fill()
 	return (consumed > 0);
 }
 
-} // namespace DevCtl
+} // namespace DevdCtl
@@ -55,14 +55,14 @@ __FBSDID("$FreeBSD$");
 //- EventBuffer Static Data ----------------------------------------------------
 /**
- * NOTIFY, NOMATCH, ATTACH, DETACH.  See DevCtlEvent::Type.
+ * NOTIFY, NOMATCH, ATTACH, DETACH.  See DevdCtlEvent::Type.
  */
 const char EventBuffer::s_eventStartTokens[] = "!?+-";

Modified: projects/zfsd/head/lib/libdevdctl/event_buffer.h
==============================================================================